==> 1.0.1.tar.gz: admmono/README.md <==
# RJ VentaBoletosAdm

## Índice

* [Configuração Inicial](#configuracao-inicial)
* [Processo de desenvolvimento](#processo-de-desenvolvimento)


## Configuração Inicial

* clonar repositórios

* Dependências
```
git clone http://18.235.188.113:3000/utilidades/Auditador.git
git clone http://18.235.188.113:3000/utilidades/generadorBoletosCNAB.git
git clone http://18.235.188.113:3000/utilidades/flyway.git
git clone http://18.235.188.113:3000/adm/modelWeb.git
git clone http://18.235.188.113:3000/adm/integracaoReceitaDespesa.git
```
* Principal
```
git clone http://18.235.188.113:3000/adm/ventaBoletosAdm.git
```

usar o <a href='http://18.235.188.113:3000/adm/ventaBoletosAdm/src/branch/master/clone.sh'>'clone.sh'</a>
ou usar o  <a href='http://18.235.188.113:3000/adm/ventaBoletosAdm/src/branch/master/AdmGit.psf'>'AdmGit.psf'</a>

****

## Processo de desenvolvimento

### Fluxo
<img src="http://18.235.188.113:3000/adm/ventaBoletosAdm/raw/branch/master/web/gui/img/GitHub-Flow-1-1024x541.png">

### Diagrama do Workflow
<img src="http://18.235.188.113:3000/adm/ventaBoletosAdm/raw/branch/master/web/gui/img/GitHub-Flow-Detalhamento.png">

### Processo

#### Passos a seguir

##### 1
* gerar uma branch baseado no caso a ser desenvolvido `git checkout -b <nome_branch>`
* realizar o envio da branch para o gitea `git push --set-upstream origin <nome_branch>`
* modificar a versão do pom baseado na regra: primeiro dígito grande melhoria, segundo dígito melhoria/adição de arquivos novos e terceiro dígito correção de bug
##### 2
* subir as modificações `git add . && git commit -m "descrição" && git push`
##### 3
* realizar o pull request diretamente no gitea
##### 4
* Necessário no mínimo 2 aprovações para validar o request
##### 5
* após OK da revisão realizar o merge para a master
* ##### SEMPRE ATENTAR PARA FAZER MERGE 1º DOS PROJETOS DAS DEPENDÊNCIAS, POIS O JENKINS ESTÁ CONFIGURADO PRA GERAR ASSIM QUE FOR FEITO MERGE NO PROJETO PRINCIPAL E A PARTIR DELE GERAR AS DEPENDÊNCIAS 
##### 6
* gerar a versão no gitea idêntica a versão gerada no pom
*  * atenção: para versão intermediária, adicionar a sigla RC + sequencial na versão (exemplo: 1.0.0-RC1)
* após gerar a versão deve ser executado no terminal os seguinte comandos para gerar o changelog `git checkout master && git pull && git log --oneline <versão anterior>...<versão gerada> --no-merges --format=format:"- **%s**%n  - %h - Autor: %aE - Data: %ci %n#"`
* adicionar o conteúdo gerado na descrição da versão

***

==> 1.0.14.tar.gz: admmono/README.md <==
# RJ VentaBoletosAdm

## Índice

* [Configuração Inicial](#configuracao-inicial)
* [Processo de desenvolvimento](#processo-de-desenvolvimento)


## Configuração Inicial

* clonar repositórios

* Dependências
```
git clone http://18.235.188.113:3000/utilidades/Auditador.git
git clone http://18.235.188.113:3000/utilidades/GeneradorBoletosCNAB.git
git clone http://18.235.188.113:3000/utilidades/Flyway.git
git clone http://18.235.188.113:3000/adm/ModelWeb.git
git clone http://18.235.188.113:3000/adm/IntegracaoReceitaDespesa.git
```
* Principal
```
git clone http://18.235.188.113:3000/adm/VentaBoletosAdm.git
```

usar o <a href='http://18.235.188.113:3000/adm/ventaBoletosAdm/src/branch/master/clone.sh'>'clone.sh'</a>
ou usar o  <a href='http://18.235.188.113:3000/adm/ventaBoletosAdm/src/branch/master/AdmGit.psf'>'AdmGit.psf'</a>

****

## Processo de desenvolvimento

### Fluxo
<img src="http://18.235.188.113:3000/adm/ventaBoletosAdm/raw/branch/master/web/gui/img/GitHub-Flow-1-1024x541.png">

### Diagrama do Workflow
<img src="http://18.235.188.113:3000/adm/ventaBoletosAdm/raw/branch/master/web/gui/img/GitHub-Flow-Detalhamento.png">

### Processo

#### Passos a seguir

##### 1
* gerar uma branch baseado no caso a ser desenvolvido `git checkout -b <nome_branch>`
* realizar o envio da branch para o gitea `git push --set-upstream origin <nome_branch>`
* modificar a versão do pom baseado na regra: primeiro dígito grande melhoria, segundo dígito melhoria/adição de arquivos novos e terceiro dígito correção de bug
##### 2
* subir as modificações `git add . && git commit -m "descrição" && git push`
##### 3
* realizar o pull request diretamente no gitea
##### 4
* Necessário no mínimo 2 aprovações para validar o request
##### 5
* após OK da revisão realizar o merge para a master
* ##### SEMPRE ATENTAR PARA FAZER MERGE 1º DOS PROJETOS DAS DEPENDÊNCIAS, POIS O JENKINS ESTÁ CONFIGURADO PRA GERAR ASSIM QUE FOR FEITO MERGE NO PROJETO PRINCIPAL E A PARTIR DELE GERAR AS DEPENDÊNCIAS 
##### 6
* gerar a versão no gitea idêntica a versão gerada no pom
*  * atenção: para versão intermediária, adicionar a sigla RC + sequencial na versão (exemplo: 1.0.0-RC1)
* após gerar a versão deve ser executado no terminal os seguinte comandos para gerar o changelog `git checkout master && git pull && git log --oneline -1 --decorate --raw --format=format:"- **%s**%n - %h - Autor: %aE - Data: %ci"`
* adicionar o conteúdo gerado na descrição da versão

***
